/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03393
 |               DRUG SERVICES RESEARCH SURVEY (DSRS), 1990
 |           (DATASET 0003: PHASE II - CLIENT RECORD ABSTRACTS)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03393-0003-statasetup.do)
 |
 **************************************************************************/

set mem 7m  /* Allocating 7 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Services Research Survey (DSRS), 1990, Dataset 0003"

#delimit ;
label define CLIENTYP  -9 "UNKNOWN/UNABLE TO DETERMINE"
                       1 "HOSPITAL IN-PATIENT" 2 "RESIDENTIAL"
                       3 "OUT-PATIENT DETOX/MAINTENANCE"
                       4 "OUT-PATIENT DRUG-FREE" 5 "ALCOHOL ONLY"
                       7 "COMBINATION (SPECIFY)" ;
label define COM_TIME  -9 "NOT RECORDED" ;
label define ABS_STAT  0 "INELIGIBLE" 1 "COMPLETE" 2 "PARTIAL COMPLETE"
                       3 "NO RECORD AVAILABLE" ;
label define TRANS_NO  -9 "UNKNOWN/NOT MENTIONED" ;
label define REABS     0 "NO, BOX NOT CHECKED" 1 "YES" ;
label define QC_ABS    0 "NO, BOX NOT CHECKED" 1 "YES, BOX CHECKED" ;
label define Q2_MO     -9 "UNKNOWN/NOT MENTIONED" ;
label define Q2_YR     -9 "UNKNOWN/NOT MENTIONED" ;
label define Q3        -9 "UNKNOWN/NOT MENTIONED" 0 "NO WAITING TIME" ;
label define Q4        -9 "UNKNOWN/NOT MENTIONED" ;
label define Q5        -9 "UNKNOWN/NOT MENTIONED" 1 "SELF" 2 "FAMILY"
                       3 "FRIEND/ACQUAINTANCE" 4 "CLERGY" 5 "SCHOOL"
                       6 "SOCIAL SERVICE AGENCY"
                       7 "EMPLOYEE ASSISTANCE PROGRAM (EAP)"
                       8 "EMPLOYER (OTHER THAN EAP)"
                       9 "CRIMINAL JUSTICE/LEGAL SYSTEM-"
                       10 "CRIMINAL JUSTICE/LEGAL SYSTEM-"
                       11 "CRIMINAL JUSTICE/LEGAL SYSTEM-"
                       12 "PRIVATE PHYSICIAN"
                       13 "COMMUNITY MENTAL HEALTH CENTER"
                       14 "OTHER HEALTH PROFESSIONAL OR PROVIDER/HOSPITAL"
                       15 "ANOTHER ALCOHOL/DRUG ABUSE TREATMENT PROGRAM"
                       88 "OTHER(SPECIFY)" ;
label define Q6        -9 "UNKNOWN/NOT MENTIONED"
                       -6 "NOT PERMITTED TO ABSTRACT"
                       1 "NO PAYMENT - PUBLIC SUBSIDY"
                       2 "NO PAYMENT - PHILANTHROPY"
                       3 "NO PAYMENT - NOT OTHERWISE SPECIFIED" 4 "SELF-PAY"
                       5 "HMO OR OTHER PREPAID PLAN"
                       6 "PRIVATE HEALTH INSURANCE" 7 "MEDICAID" 8 "MEDICARE"
                       9 "DOD" 10 "CHAMPUS" 11 "VA" 12 "SOCIAL SERVICES"
                       13 "PUBLIC HOUSING/HOME RELIEF" 88 "OTHER(SPECIFY)" ;
label define Q7        -9 "UNKNOWN/NOT MENTIONED"
                       -6 "NOT PERMITTED TO ABSTRACT"
                       1 "NO PAYMENT - PUBLIC SUBSIDY"
                       2 "NO PAYMENT - PHILANTHROPY"
                       3 "NO PAYMENT - NOT OTHERWISE SPECIFIED" 4 "SELF-PAY"
                       5 "HMO OR OTHER PREPAID PLAN"
                       6 "PRIVATE HEALTH INSURANCE" 7 "MEDICAID" 8 "MEDICARE"
                       9 "DOD" 10 "CHAMPUS" 11 "VA" 12 "SOCIAL SERVICES"
                       13 "PUBLIC HOUSING/HOME RELIEF" 88 "OTHER(SPECIFY)" ;
label define Q8_MO     -9 "UNKNOWN/NOT MENTIONED" ;
label define Q8_YR     -9 "UNKNOWN/NOT MENTIONED" ;
label define Q10       -9 "UNKNOWN/NOT MENTIONED" ;
label define Q11       -9 "UNKNOWN/NOT MENTIONED" 1 "MALE" 2 "FEMALE"
                       8 "OTHER (SPECIFY)" ;
label define Q12       -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       1 "WHITE" 2 "BLACK" 3 "AMERICAN INDIAN"
                       4 "ALASKAN NATIVE" 5 "ASIAN OR PACIFIC ISLANDER"
                       8 "OTHER (SPECIFY)" ;
label define Q13       -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       1 "HISPANIC" 2 "NOT OF HISPANIC ORIGIN"
                       8 "OTHER (SPECIFY)" ;
label define Q14       -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       0 "NEVER MARRIED" 1 "MARRIED/COMMON LAW" 2 "WIDOWED"
                       3 "SEPARATED/DIVORCED" 4 "SINGLE" 8 "OTHER (SPECIFY)" ;
label define Q15       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES" ;
label define Q16       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES" ;
label define Q17       -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       0 "NO STABLE ARRANGEMENT(INCLUDE HOMELESS, SHELTERS)"
                       1 "WITH PARTNER/SPOUSE" 2 "WITH PARENT(S)"
                       3 "WITH OTHER FAMILY" 4 "WITH UNRELATED OTHER(S)"
                       5 "ALONE" 6 "WITH NO OTHER ADULT(S)"
                       7 "CONTROLLED ENVIRONMENT" 8 "OTHER (SPECIFY)" ;
label define Q18       -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       1 "LESS THAN 8 YEARS" 2 "8-11 YEARS"
                       3 "< H.S. GRADUATE, NOT OTHERWISE SPECIFIED"
                       4 "H.S. GRADUATE/GED" 5 "SOME COLLEGE"
                       6 "COLLEGE GRADUATE" 7 "POSTGRADUATE"
                       8 "OTHER (SPECIFY)" ;
label define Q19       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES" ;
label define Q20       -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       1 "FULL-TIME (35 HRS/WK OR MORE)"
                       2 "PART-TIME (LESS THAN 35 HRS/WK)"
                       3 "EMPLOYED, NOT OTHERWISE SPECIFIED"
                       4 "KEEPING HOUSE, NOT OTHERWISE EMPLOYED"
                       5 "UNEMPLOYED - RETIRED" 6 "UNEMPLOYED - DISABLED"
                       7 "UNEMPLOYED, NOT OTHERWISE SPECIFIED"
                       8 "OTHER (SPECIFY)" ;
label define Q21       -9 "UNKNOWN/NOT MENTIONED" 1 "OCCUPATION GIVEN" ;
label define Q22       -9 "UNKNOWN/NOT MENTIONED" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define Q23       -9 "UNKNOWN/NOT MENTIONED" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define Q24       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define Q25       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define Q26       -9 "UNKNOWN/NOT MENTIONED" 0 "NONE" ;
label define Q27       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES" ;
label define Q28       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES" ;
label define Q29       -9 "UNKNOWN/NOT MENTIONED" 0 "NO"
                       1 "YES, SPECIFY BELOW" ;
label define Q29A      -9 "UNKNOWN / NOT ASCERTAINED"
                       -5 "INAP - Q29 = NO or MISSING"
                       1 "MENTAL ILLNESS SPECIFIED" ;
label define Q29A_MC1  -5 "INAP - DUAL DIAGNOSIS NOT INDICATED"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q29A_MC2  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED"
                       -5 "INAP - MULTIPLE DUAL DIAGNOSES NOT INDICATED"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q29A_MC3  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED"
                       -5 "INAP - MULTIPLE DUAL DIAGNOSES NOT INDICATED"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q29A_MC4  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED"
                       -5 "INAP - MULTIPLE DUAL DIAGNOSES NOT INDICATED"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q30       -9 "UNKNOWN/NOT MENTIONED" -5 "INAP - MALE CLIENT"
                       0 "NOT PREGNANT" 1 "PREGNANT" ;
label define Q31       -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       1 "SINGLE DRUG ABUSE ONLY (EXCLUDING ALCOHOL)"
                       2 "POLYDRUG ABUSE ONLY (EXCLUDING ALCOHOL)"
                       3 "ALCOHOL ABUSE ONLY"
                       4 "ALCOHOL ABUSE AND ABUSE OF ONE OTHER DRUG COMBINED"
                       5 "ALCOHOL ABUSE AND ABUSE OF TWO OR MORE OTHER DRUGS COMBINED" ;
label define Q32       -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       1 "SINGLE DRUG ABUSE ONLY (EXCLUDING ALCOHOL)"
                       2 "POLYDRUG ABUSE ONLY (EXCLUDING ALCOHOL)"
                       3 "ALCOHOL ABUSE ONLY"
                       4 "ALCOHOL AND OTHER DRUGS ABUSE COMBINED" ;
label define Q33       -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q33A      -9 "UNKNOWN / NOT MENTIONED"
                       1 "PRIMARY DIAGNOSIS SPECIFIED" ;
label define Q33A_MC1  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "INAP"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q33B_MC1  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED"
                       -5 "INAP - MULTIPLE DIAGNOSES NOT AVAILABLE"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q33B_MC2  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED"
                       -5 "INAP - MULTIPLE DIAGNOSES NOT AVAILABLE"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q33B_MC3  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "INAP"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q33B_MC4  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "INAP"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q33B_MC5  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "INAP"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q33B_MC6  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "INAP"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q33B      -9 "UNKNOWN - NOT MENTIONED"
                       1 "PRIMARY DIAGNOSIS SPECIFIED" ;
label define Q33B1     -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q33B2     -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "INAP"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q35_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q35_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - COCAINE USE NOT INDICATED" 0 "NO" 1 "YES" ;
label define Q35_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - COCAINE USE NOT INDICATED" ;
label define Q36_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q36_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - CRACK USE NOT INDICATED" 0 "NO" 1 "YES" ;
label define Q36_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - CRACK USE NOT INDICATED" ;
label define Q37_EVER  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - HERION USE NOT INDICATED" 0 "NO/NEVER USED"
                       1 "YES" ;
label define Q37_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - HERION USE NOT INDICATED" 0 "NO" 1 "YES" ;
label define Q37_AGE   -9 "UNKNOWN / NOT MENTIONED"
                       -5 "INAP - HERION USE NOT INDICATED" ;
label define Q38_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q38_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NON-TREAT METHADONE NOT INDICATED" 0 "NO"
                       1 "YES" ;
label define Q38_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NON-TREAT METHADONE NOT INDICATED" ;
label define Q39_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q39_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER OPIATE USE NOT INDICATED" 0 "NO"
                       1 "YES" ;
label define Q39_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER OPIATE USE NOT INDICATED" ;
label define Q40_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q40_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - BARBITURATE USE NOT INDICATED" 0 "NO"
                       1 "YES" ;
label define Q40_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - BARBITURATE USE NOT INDICATED" ;
label define Q41_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q41_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - BENZODIAZEPINE USE NOT INDICATED" 0 "NO"
                       1 "YES" ;
label define Q41_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER USE NOT INDICATED" ;
label define Q42_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q42_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER SED USE NOT INDICATED" 0 "NO" 1 "YES" ;
label define Q42_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER SEDATIVE USE NOT INDICATED" ;
label define Q43_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q43_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - METHAMPHETAMINE USE NOT INDICATED" 0 "NO"
                       1 "YES" ;
label define Q43_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER METHAMPHETAMINE USE NOT INDICATED" ;
label define Q44_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q44_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER AMPHETAMINE USE NOT INDICATED" 0 "NO"
                       1 "YES" ;
label define Q44_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER AMPHETAMINE USE NOT INDICATED" ;
label define Q45_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q45_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER USE NOT INDICATED" 0 "NO" 1 "YES" ;
label define Q45_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER MJ, HASHISH, THC, USE NOT INDICATED" ;
label define Q46_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q46_USED  -9 "UNKNOWN/NOT MENTIONED" -5 "INAP - LOGICAL SKIP"
                       0 "NO" 1 "YES" ;
label define Q46_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - PCP/LSD USE NOT INDICATED" ;
label define Q47_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q47_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER HALLUCINOGEN USE NOT INDICATED"
                       0 "NO" 1 "YES" ;
label define Q47_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER HALLUCINOGEN USE NOT INDICATED" ;
label define Q48_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q48_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - INHALANT USE NOT INDICATED" 0 "NO" 1 "YES" ;
label define Q48_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER INHALANT USE NOT INDICATED" ;
label define Q49_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q49_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OVER-THE-COUTNER USE NOT INDICATED" 0 "NO"
                       1 "YES" ;
label define Q49_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER OVER-THE-COUNTER USE NOT INDICATED" ;
label define Q50_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q50_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - ALCOHOL USE NOT INDICATED" 0 "NO" 1 "YES" ;
label define Q50_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER ALCOHOL USE NOT INDICATED" ;
label define Q51_EVER  -9 "UNKNOWN/NOT MENTIONED" 0 "NO/NEVER USED" 1 "YES" ;
label define Q51_USED  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER USE NOT INDICATED" 0 "NO" 1 "YES" ;
label define Q51_AGE   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - OTHER USE NOT INDICATED" ;
label define Q52       -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DRUG OF CHOICE NOT SPECIFIED AT ADMISSION"
                       0 "NO DRUG OF CHOICE" 35 "COCAINE" 36 "CRACK"
                       37 "HEROIN" 38 "NON-TREATMENT METHADONE"
                       39 "OTHER OPIATES/SYNTHETICS" 40 "BARBITURATES"
                       41 "BENZODIAZEPINES" 42 "OTHER SEDATIVES/HYPNOTICS"
                       43 "METHAMPHETAMINES" 44 "OTHER AMPHETAMINES"
                       45 "MARIJUANA/HASHISH/THC" 46 "PCP/LSD"
                       47 "OTHER HALLUCINOGENS" 48 "INHALANTS"
                       49 "OVER-THE-COUNTER" 50 "ALCOHOL" 51 "OTHER" ;
label define Q53A      -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES" ;
label define Q53B      -9 "UNKNOWN / NOT MENTIONED"
                       -5 "INAP - NO LIFE TIME IDU INDICATED" 0 "NO" 1 "YES" ;
label define Q53C      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO IDU INDICATED AT ADMISSION" 1 "DAILY"
                       2 "REGULARLY BUT NOT DAILY" 3 "SPORADICALLY" ;
label define Q54       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES" ;
label define Q54_TST1  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER (SPECIFY)"
                       -5 "INAP - Q54 = 0 OR MISSING" 1 "URINE"
                       2 "SERUM/BLOOD" 8 "OTHER SPECIFY" ;
label define Q54_TST2  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER (SPECIFY)"
                       -5 "INAP - Q54=0 OR MISSING, OR ONLY ONE TEST"
                       1 "URINE" 2 "SERUM/BLOOD" 8 "OTHER SPECIFY" ;
label define Q54_MO1   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - Q54=0 OR MISSING" ;
label define Q54_YR1   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - Q54=0 OR MISSING" ;
label define Q54_MO2   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - Q54=0 OR MISSING" ;
label define Q54_YR2   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - Q54=0 OR MISSING" ;
label define Q54A_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54A_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54B_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54B_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54C_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54C_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54D_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54D_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54E_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54E_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54F_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54F_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54G_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54G_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54H_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54H_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54I_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54I_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54J_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54J_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54K_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54K_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54L_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54L_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54M_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54M_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54N_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54N_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54O_1    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q54O_2    -5 "BLANK - NOT CHECKED" 1 "POSITIVE" ;
label define Q55       -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP-NO SUBSTANCE ABUSE TESTING INDICATED" ;
label define Q56       -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP-NO SUBSTANCE ABUSE TESTING INDICATED"
                       0 "NONE" ;
label define Q57       -9 "UNKNOWN/NOT MENTIONED" ;
label define Q57A      -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER (SPECIFY)"
                       -5 "INAP - NO PREVIOUS TX EPISODES"
                       0 "LESS THAN 6 MONTHS" 55 "LIFETIME" ;
label define Q58       -9 "UNKOWN / NOT MENTIONED"
                       -5 "INAP - NO PREVIOUS TX EPISODES" 0 "NO" 1 "YES"
                       2 "YES, DATA OVERFLOW" ;
label define Q58_NO    -9 "9 OR MORE TREATMENT EPISODES"
                       -5 "INAP-NO PRIOR TREATMENT EPISODES" 9 "9 OR MORE" ;
label define Q58A_PRI  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP-NO PRIOR TREATMENT EPISODES" 1 "COCAINE"
                       2 "CRACK" 3 "HEROIN" 4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER - SPECIFY"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER - SPECIFY" ;
label define Q58A_SEC  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -7 "RECORD STATES NO SECONDARY DRUG USE"
                       -5 "INAP-NO PRIOR TREATMENT EPISODES" 1 "COCAINE"
                       2 "CRACK" 3 "HEROIN" 4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER - SPECIFY"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       77 "RECORD STATES NO SECONDARY DRUG USE"
                       88 "OTHER - SPECIFY" ;
label define Q58A_FAC  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO PRIOR TREATMENT EPISODES" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q58A_RES  -9 "UNKNOWN/NOT ASCERTAINED" -8 "OTHER(SPECIFY)"
                       -5 "INAP - Logical Skip"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TREATMENT, REFERRED"
                       3 "DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE"
                       4 "DID NOT COMPLETE TREATMENT BY CLIENT CHOICE"
                       5 "DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE"
                       6 "INCARCERATED" 8 "OTHER - SPECIFY" ;
label define Q58B_PRI  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -7 "RECORD STATES NO SECONDARY DRUG USE" -5 "INAP"
                       1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER - SPECIFY" ;
label define Q58B_SEC  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -7 "RECORD STATES NO SECONDARY DRUG USE" -5 "INAP"
                       1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58B_FAC  -9 "UNKNOWN/NOT MENTIONED" -5 "INAP" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q58B_RES  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP - Logical Skip"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TREATMENT, REFERRED"
                       3 "DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE"
                       4 "DID NOT COMPLETE TREATMENT BY CLIENT CHOICE"
                       5 "DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE"
                       6 "INCARCERATED" 8 "OTHER (SPECIFY)" ;
label define Q58C_PRI  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP" 1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58C_SEC  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -7 "RECORD STATES NO SECONDARY DRUG USE" -5 "INAP"
                       1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58C_FAC  -9 "UNKNOWN/NOT MENTIONED" -5 "INAP" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q58C_RES  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP - Logical Skip"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TREATMENT, REFERRED"
                       3 "DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE"
                       4 "DID NOT COMPLETE TREATMENT BY CLIENT CHOICE"
                       5 "DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE"
                       6 "INCARCERATED" ;
label define Q58D_PRI  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP" 1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58D_SEC  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -7 "RECORD STATES NO SECONDARY DRUG USE" -5 "INAP"
                       1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58D_FAC  -9 "UNKNOWN/NOT MENTIONED" -5 "INAP" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q58D_RES  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP - Logical Skip"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TREATMENT, REFERRED"
                       3 "DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE"
                       4 "DID NOT COMPLETE TREATMENT BY CLIENT CHOICE"
                       5 "DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE"
                       6 "INCARCERATED" ;
label define Q58E_PRI  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP" 1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58E_SEC  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -7 "RECORD STATES NO SECONDARY DRUG USE" -5 "INAP"
                       1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58E_FAC  -9 "UNKNOWN/NOT MENTIONED" -5 "INAP" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q58E_RES  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP - Logical Skip"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TREATMENT, REFERRED"
                       3 "DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE"
                       4 "DID NOT COMPLETE TREATMENT BY CLIENT CHOICE"
                       5 "DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE"
                       6 "INCARCERATED" ;
label define Q58F_PRI  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP" 1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58F_SEC  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -7 "RECORD STATES NO SECONDARY DRUG USE" -5 "INAP"
                       1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58F_FAC  -9 "UNKNOWN/NOT MENTIONED" -5 "INAP" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q58F_RES  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP - Logical Skip"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TREATMENT, REFERRED"
                       3 "DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE"
                       4 "DID NOT COMPLETE TREATMENT BY CLIENT CHOICE"
                       5 "DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE"
                       6 "INCARCERATED" ;
label define Q58G_PRI  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP" 1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58G_SEC  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -7 "RECORD STATES NO SECONDARY DRUG USE" -5 "INAP"
                       1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58G_FAC  -9 "UNKNOWN/NOT MENTIONED" -5 "INAP" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q58G_RES  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP - Logical Skip"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TREATMENT, REFERRED"
                       3 "DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE"
                       4 "DID NOT COMPLETE TREATMENT BY CLIENT CHOICE"
                       5 "DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE"
                       6 "INCARCERATED" ;
label define Q58H_PRI  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP" 1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58H_SEC  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -7 "RECORD STATES NO SECONDARY DRUG USE" -5 "INAP"
                       1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58H_FAC  -9 "UNKNOWN/NOT MENTIONED" -5 "INAP" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q58H_RES  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP - Logical Skip"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TREATMENT, REFERRED"
                       3 "DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE"
                       4 "DID NOT COMPLETE TREATMENT BY CLIENT CHOICE"
                       5 "DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE"
                       6 "INCARCERATED" ;
label define Q58I_PRI  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP" 1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58I_SEC  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -7 "RECORD STATES NO SECONDARY DRUG USE" -5 "INAP"
                       1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58I_FAC  -9 "UNKNOWN/NOT MENTIONED" -5 "INAP" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q58I_RES  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP - Logical Skip"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TREATMENT, REFERRED"
                       3 "DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE"
                       4 "DID NOT COMPLETE TREATMENT BY CLIENT CHOICE"
                       5 "DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE"
                       6 "INCARCERATED" ;
label define Q58J_PRI  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP" 1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58J_SEC  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -7 "RECORD STATES NO SECONDARY DRUG USE" -5 "INAP"
                       1 "COCAINE" 2 "CRACK" 3 "HEROIN"
                       4 "NON-TREATMENT METHADONE"
                       5 "OTHER OPIATES/SYNTHETICS" 6 "BARBITUATES"
                       7 "BENZODIAZEPINES" 8 "OTHER SEDATIVES/HYPNOTICS"
                       9 "METHAMPHETAMINES" 10 "OTHER AMPHETAMINES"
                       11 "MARIJUANA/HASHISH/THC" 12 "PCP/LSD"
                       13 "OTHER HALLUCINOGENS" 14 "INHALANTS" 15 "ALCOHOL"
                       16 "POLYDRUG (EXCLUDING ALCOHOL)"
                       17 "COMBINATION ALCOHOL AND OTHER DRUG"
                       18 "SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)"
                       88 "OTHER (SPECIFY)" ;
label define Q58J_FAC  -9 "UNKNOWN/NOT MENTIONED" -5 "INAP" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q58J_RES  -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -5 "INAP - Logical Skip"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TREATMENT, REFERRED"
                       3 "DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE"
                       4 "DID NOT COMPLETE TREATMENT BY CLIENT CHOICE"
                       5 "DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE"
                       6 "INCARCERATED" ;
label define Q59_SER   -9 "UNKNOWN/NOT MENTIONED" 0 "NOT GIVEN"
                       1 "ACTUALLY GIVEN, COMPLETED"
                       2 "ACTUALLY GIVEN, NOT COMPLETED"
                       3 "ACTUALLY GIVEN, NOT COMPLETED"
                       4 "ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED"
                       5 "PLANNED OR RECOMMENDED, CAN'T CONFIRM ACTUALLY GIVEN" ;
label define Q59_FAC   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO IND COUNSELING INDICATED" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q59_NO    -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO IND COUNSELING INDICATED" 0 "NONE" ;
label define Q60_SER   -9 "UNKNOWN/NOT MENTIONED" 0 "NOT GIVEN"
                       1 "ACTUALLY GIVEN, COMPLETED"
                       2 "ACTUALLY GIVEN, NOT COMPLETED"
                       3 "ACTUALLY GIVEN, NOT COMPLETED"
                       4 "ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED"
                       5 "PLANNED OR RECOMMENDED, CAN'T CONFIRM ACTUALLY GIVEN" ;
label define Q60_FAC   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO DRUG EDUCATION INDICATED" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q60_NO    -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO GROUP COUNSELING INDICATED" 0 "NONE" ;
label define Q61_SER   -9 "UNKNOWN/NOT MENTIONED" 0 "NOT GIVEN"
                       1 "ACTUALLY GIVEN, COMPLETED"
                       2 "ACTUALLY GIVEN, NOT COMPLETED"
                       3 "ACTUALLY GIVEN, NOT COMPLETED"
                       4 "ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED"
                       5 "PLANNED OR RECOMMENDED, CAN'T CONFIRM ACTUALLY GIVEN" ;
label define Q61_FAC   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - FAMILY COUNSELING NOT GIVEN" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q61_NO    -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO FAMILY COUNSELING INDICATED" 0 "NONE" ;
label define Q62_SER   -9 "UNKNOWN/NOT MENTIONED" 0 "NOT GIVEN"
                       1 "ACTUALLY GIVEN, COMPLETED"
                       2 "ACTUALLY GIVEN, NOT COMPLETED"
                       3 "ACTUALLY GIVEN, NOT COMPLETED"
                       4 "ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED"
                       5 "PLANNED OR RECOMMENDED, CAN'T CONFIRM ACTUALLY GIVEN" ;
label define Q62_FAC   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO DRUG EDUCATION INDICATED" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q62_NO    -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO DRUG EDUCATION INDICATED" 0 "NONE" ;
label define Q63_SER   -9 "UNKNOWN/NOT MENTIONED" 0 "NOT GIVEN"
                       1 "ACTUALLY GIVEN, COMPLETED"
                       2 "ACTUALLY GIVEN, NOT COMPLETED"
                       3 "ACTUALLY GIVEN, NOT COMPLETED"
                       4 "ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED"
                       5 "PLANNED OR RECOMMENDED, CAN'T CONFIRM ACTUALLY GIVEN" ;
label define Q63_FAC   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO EMPLOYMENT COUNSELING INDICATED"
                       1 "HERE" 2 "ELSEWHERE" ;
label define Q64_SER   -9 "UNKNOWN/NOT MENTIONED" 0 "NOT GIVEN"
                       1 "ACTUALLY GIVEN, COMPLETED"
                       2 "ACTUALLY GIVEN, NOT COMPLETED"
                       3 "ACTUALLY GIVEN, NOT COMPLETED"
                       4 "ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED"
                       5 "PLANNED OR RECOMMENDED, CAN'T CONFIRM ACTUALLY GIVEN" ;
label define Q64_FAC   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO JOB TRAINING INDICATED" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q65_SER   -9 "UNKNOWN/NOT MENTIONED" 0 "NOT GIVEN"
                       1 "ACTUALLY GIVEN, COMPLETED"
                       2 "ACTUALLY GIVEN, NOT COMPLETED"
                       3 "ACTUALLY GIVEN, NOT COMPLETED"
                       4 "ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED"
                       5 "PLANNED OR RECOMMENDED, CAN'T CONFIRM ACTUALLY GIVEN" ;
label define Q65_FAC   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO EDUCATIONAL CLASSES INDICATED" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q66_SER   -9 "UNKNOWN/NOT MENTIONED" 0 "NOT GIVEN"
                       1 "ACTUALLY GIVEN, COMPLETED"
                       2 "ACTUALLY GIVEN, NOT COMPLETED"
                       3 "ACTUALLY GIVEN, NOT COMPLETED"
                       4 "ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED"
                       5 "PLANNED OR RECOMMENDED, CAN'T CONFIRM ACTUALLY GIVEN" ;
label define Q66_FAC   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO DETOXIFICATION INDICATED" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q67_SER   -9 "UNKNOWN/NOT MENTIONED" 0 "NOT GIVEN"
                       1 "ACTUALLY GIVEN, COMPLETED"
                       2 "ACTUALLY GIVEN, NOT COMPLETED"
                       3 "ACTUALLY GIVEN, NOT COMPLETED"
                       4 "ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED"
                       5 "PLANNED OR RECOMMENDED, CAN'T CONFIRM ACTUALLY GIVEN" ;
label define Q67_FAC   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - ACTIVITY GROUPS INDICATED" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q68_SER   -9 "UNKNOWN/NOT MENTIONED" 0 "NOT GIVEN"
                       1 "ACTUALLY GIVEN, COMPLETED"
                       2 "ACTUALLY GIVEN, NOT COMPLETED"
                       3 "ACTUALLY GIVEN, NOT COMPLETED"
                       4 "ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED"
                       5 "PLANNED OR RECOMMENDED, CAN'T CONFIRM ACTUALLY GIVEN" ;
label define Q68_FAC   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - SELF HELP NOT INDICATED" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q69_SER   -9 "UNKNOWN/NOT MENTIONED" 0 "NOT GIVEN"
                       1 "ACTUALLY GIVEN, COMPLETED"
                       2 "ACTUALLY GIVEN, NOT COMPLETED"
                       3 "ACTUALLY GIVEN, NOT COMPLETED"
                       4 "ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED"
                       5 "PLANNED OR RECOMMENDED, CAN'T CONFIRM ACTUALLY GIVEN" ;
label define Q69_FAC   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DAY CARE NOT INDICATED" 1 "HERE"
                       2 "ELSEWHERE" ;
label define Q70       -9 "UNKNOWN/NOT MENTIONED" 0 "NO"
                       1 "YES, SPECIFY BELOW" ;
label define Q70A      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP-MEDICATIONS NOT PRESCRIBED"
                       1 "MEDICATIONS SPECIFIED" ;
label define Q71       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES" ;
label define Q72       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES" ;
label define Q73       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES" ;
label define Q74       -9 "UNKNOWN/NOT MENTIONED" 0 "NO" 1 "YES" ;
label define Q74A_MO   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" ;
label define Q74A_YR   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" ;
label define Q74A_TOT  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" ;
label define Q74A_GIV  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" ;
label define Q74A_NO   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" ;
label define Q74A_PL   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" 1 "HERE" 2 "AT HOME"
                       3 "HERE/AT HOME" ;
label define Q74B_MO   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" ;
label define Q74B_YR   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" ;
label define Q74B_TOT  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" ;
label define Q74B_GIV  -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" ;
label define Q74B_NO   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" ;
label define Q74B_PL   -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" 1 "HERE" 2 "AT HOME"
                       3 "HERE/AT HOME" ;
label define Q75       -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO METHADONE GIVEN" 0 "NO" 1 "YES" ;
label define Q76       -9 "UNKNOWN/NOT MENTIONED" 0 "CLIENT DECEASED"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TX, REFERRED TO ANOTHER PROGRAM"
                       3 "DID NOT COMPLETE TX BY ADMINISTRATION CHOICE"
                       4 "DID NOT COMPLETE TX BY CLIENT CHOICE"
                       5 "DID NOT COMPLETE TX, NOT MENTIONED WHOSE CHOICE"
                       6 "INCARCERATED" 8 "OTHER (SPECIFY)" ;
label define Q76A_MO   -9 "UNKNOWN - NOT MENTIONED" -5 "INAP - NOT DECEASED" ;
label define Q76A_YR   -9 "UNKNOWN - NOT MENTIONED" -5 "INAP - NOT DECEASED" ;
label define Q76B      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - Q76 CODED 1,2,3,6, OR -9"
                       1 "REASON SPECIFIED" ;
label define Q77_MO    -9 "UNKNOWN/NOT MENTIONED" ;
label define Q77_YR    -9 "UNKNOWN/NOT MENTIONED" ;
label define Q78_MO    -9 "UNKNOWN/NOT MENTIONED" ;
label define Q78_YR    -9 "UNKNOWN/NOT MENTIONED" ;
label define Q79       -9 "UNKNOWN / NOT MENTIONED" 0 "NO"
                       1 "YES, SPECIFY BELOW" ;
label define Q79A      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - NO DUAL DIAGNOSIS INDICATED"
                       1 "MENTAL ILLNESS SPECIFIED" ;
label define Q79A_MC1  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED"
                       -5 "Inap - Logical Skip" 0 "NO DIAGNOSIS"
                       1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q79A_MC2  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED"
                       -5 "Inap - Logical Skip" 0 "NO DIAGNOSIS"
                       1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q79A_MC3  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED"
                       -5 "Inap - Logical Skip" 0 "NO DIAGNOSIS"
                       1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q79A_MC4  -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED"
                       -5 "Inap - Logical Skip" 0 "NO DIAGNOSIS"
                       1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define Q80       -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DID NOT COMPLETE TX" 0 "NO" 1 "YES" ;
label define Q81       -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED"
                       1 "YES, SERVICES SPECIFIED" ;
label define Q81A      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED"
                       0 "NO" 1 "YES" ;
label define Q81B      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED"
                       0 "NO" 1 "YES" ;
label define Q81C      -9 "UNKNOWN/NOT MENTIONED" -7 "NOT ROUTINELY RECORDED"
                       -5 "INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED"
                       0 "NO" 1 "YES" ;
label define Q81D      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED"
                       0 "NO" 1 "YES" ;
label define Q81E      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED"
                       0 "NO" 1 "YES" ;
label define Q81F      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED"
                       0 "NO" 1 "YES" ;
label define Q81G      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED"
                       0 "NO" 1 "YES" ;
label define Q81H      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED"
                       0 "NO" 1 "YES" ;
label define Q81I      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED"
                       0 "NO" 1 "YES" ;
label define Q81J      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED"
                       0 "NO" 1 "YES" ;
label define Q82       -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       0 "NO TREATMENT" 1 "HOSPITAL INPATIENT"
                       2 "RESIDENTIAL" 3 "OUTPATIENT/METHADONE MAINTENANCE"
                       4 "OTHER OUTPATIENT" 8 "OTHER (SPECIFY)" ;
label define Q83       -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER (SPECIFY)"
                       -6 "NOT PERMITTED TO ABSTRACT" 0 "NO CHARGES" ;
label define Q83A      -9 "UNKNOWN/NOT MENTIONED"
                       -5 "INAP - CHARGES WERE BILLED" 0 "NO" 1 "YES" ;
label define Q84       -9 "UNKNOWN/NOT MENTIONED"
                       -6 "NOT PERMITTED TO ABSTRACT" 0 "NO CHARGES"
                       1 "FULL AMOUNT BILLED" 2 "SLIDING FEE AMOUNT"
                       3 "REDUCED AMOUNT (SPECIFY % OF TOTAL IN Q84_PER)"
                       8 "OTHER (SPECIFY)" ;
label define Q84_PER   -9 "UNKNOWN/NOT MENTIONED" -8 "OTHER(SPECIFY)"
                       -6 "NOT PERMITTED TO ABSTRACT"
                       -5 "INAP - NOT REDUCED AMOUNT" ;
label define Q85       -5 "NO COMMENTS LISTED" 1 "COMMENTS LISTED" ;
label define CORRFAC   0 "NO" 1 "YES" ;
label define ALCHONLY  0 "NO" 1 "YES" ;
label define STRATUM   1 "HOSPITAL IN-PATIENT DRUG TREATMENT"
                       2 "RESIDENTIAL DRUG TREATMENT"
                       3 "OUT-PATIENT DRUG DETOXIFICATION MAINTENANCE"
                       4 "OUT-PATIENT DRUG-FREE TREATMENT"
                       5 "ALCOHOL TREATMENT ONLY" 6 "UNKNOWN TREATMENT TYPE" ;
label define REGION    1 "NORTHEAST" 2 "NORTH CENTRAL" 3 "SOUTH" 4 "WEST" ;
label define LOS       -9 "MISSING DATA - NOT ABLE TO BE DERIVED" ;
label define TRT_DUR   -9 "MISSING DATA - NOT ABLE TO BE DERIVED" ;
label define AGEA      -9 "MISSING DATA - NOT ABLE TO BE DERIVED" ;
label define AGED      -9 "MISSING DATA - NOT ABLE TO BE DERIVED" ;
label define TXTYPE    -9 "UNKNOWN/UNABLE TO DETERMINE"
                       1 "HOSPITAL IN-PATIENT" 2 "RESIDENTIAL" 3 "METHADONE"
                       4 "OUT-PATIENT DRUG FREE" 5 "ALCOHOL" 7 "COMBINATION" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CASEID = . if (CASEID <= -1 )
replace OBS_NUM = . if (OBS_NUM <= -1 )
replace CLIENTYP = . if (CLIENTYP <= -1 )
replace ABSTRACT = . if (ABSTRACT <= -1 )
replace COMP_MO = . if (COMP_MO <= -1 )
replace COMP_YR = . if (COMP_YR <= -1 )
replace COM_TIME = . if (COM_TIME <= -1 )
replace ABS_STAT = . if (ABS_STAT <= -1 )
replace TRANS_NO = . if (TRANS_NO <= -1 )
replace REABS = . if (REABS <= -1 )
replace QC_ABS = . if (QC_ABS <= -1 )
replace Q2_MO = . if (Q2_MO <= -1 )
replace Q2_YR = . if (Q2_YR <= -1 )
replace Q3 = . if (Q3 <= -1 )
replace Q4 = . if (Q4 <= -1 )
replace Q5 = . if (Q5 <= -1 )
replace Q6 = . if (Q6 <= -1 )
replace Q7 = . if (Q7 <= -1 )
replace Q8_MO = . if (Q8_MO <= -1 )
replace Q8_YR = . if (Q8_YR <= -1 )
replace Q10 = . if (Q10 <= -1 )
replace Q11 = . if (Q11 <= -1 )
replace Q12 = . if (Q12 <= -1 )
replace Q13 = . if (Q13 <= -1 )
replace Q14 = . if (Q14 <= -1 )
replace Q15 = . if (Q15 <= -1 )
replace Q16 = . if (Q16 <= -1 )
replace Q17 = . if (Q17 <= -1 )
replace Q18 = . if (Q18 <= -1 )
replace Q19 = . if (Q19 <= -1 )
replace Q20 = . if (Q20 <= -1 )
replace Q21 = . if (Q21 <= -1 )
replace Q21_OCC = . if (Q21_OCC <= -1 )
replace Q22 = . if (Q22 <= -1 )
replace Q23 = . if (Q23 <= -1 )
replace Q24 = . if (Q24 <= -1 )
replace Q25 = . if (Q25 <= -1 )
replace Q26 = . if (Q26 <= -1 )
replace Q27 = . if (Q27 <= -1 )
replace Q28 = . if (Q28 <= -1 )
replace Q29 = . if (Q29 <= -1 )
replace Q29A = . if (Q29A <= -1 )
replace Q29A_MC1 = . if (Q29A_MC1 <= -1 )
replace Q29A_MC2 = . if (Q29A_MC2 <= -1 )
replace Q29A_MC3 = . if (Q29A_MC3 <= -1 )
replace Q29A_MC4 = . if (Q29A_MC4 <= -1 )
replace Q30 = . if (Q30 <= -1 )
replace Q31 = . if (Q31 <= -1 )
replace Q32 = . if (Q32 <= -1 )
replace Q33 = . if (Q33 <= -1 )
replace Q33A = . if (Q33A <= -1 )
replace Q33A_MC1 = . if (Q33A_MC1 <= -1 )
replace Q33B_MC1 = . if (Q33B_MC1 <= -1 )
replace Q33B_MC2 = . if (Q33B_MC2 <= -1 )
replace Q33B_MC3 = . if (Q33B_MC3 <= -1 )
replace Q33B_MC4 = . if (Q33B_MC4 <= -1 )
replace Q33B_MC5 = . if (Q33B_MC5 <= -1 )
replace Q33B_MC6 = . if (Q33B_MC6 <= -1 )
replace Q33B = . if (Q33B <= -1 )
replace Q33B1 = . if (Q33B1 <= -1 )
replace Q33B2 = . if (Q33B2 <= -1 )
replace Q35_EVER = . if (Q35_EVER <= -1 )
replace Q35_USED = . if (Q35_USED <= -1 )
replace Q35_AGE = . if (Q35_AGE <= -1 )
replace Q36_EVER = . if (Q36_EVER <= -1 )
replace Q36_USED = . if (Q36_USED <= -1 )
replace Q36_AGE = . if (Q36_AGE <= -1 )
replace Q37_EVER = . if (Q37_EVER <= -1 )
replace Q37_USED = . if (Q37_USED <= -1 )
replace Q37_AGE = . if (Q37_AGE <= -1 )
replace Q38_EVER = . if (Q38_EVER <= -1 )
replace Q38_USED = . if (Q38_USED <= -1 )
replace Q38_AGE = . if (Q38_AGE <= -1 )
replace Q39_EVER = . if (Q39_EVER <= -1 )
replace Q39_USED = . if (Q39_USED <= -1 )
replace Q39_AGE = . if (Q39_AGE <= -1 )
replace Q40_EVER = . if (Q40_EVER <= -1 )
replace Q40_USED = . if (Q40_USED <= -1 )
replace Q40_AGE = . if (Q40_AGE <= -1 )
replace Q41_EVER = . if (Q41_EVER <= -1 )
replace Q41_USED = . if (Q41_USED <= -1 )
replace Q41_AGE = . if (Q41_AGE <= -1 )
replace Q42_EVER = . if (Q42_EVER <= -1 )
replace Q42_USED = . if (Q42_USED <= -1 )
replace Q42_AGE = . if (Q42_AGE <= -1 )
replace Q43_EVER = . if (Q43_EVER <= -1 )
replace Q43_USED = . if (Q43_USED <= -1 )
replace Q43_AGE = . if (Q43_AGE <= -1 )
replace Q44_EVER = . if (Q44_EVER <= -1 )
replace Q44_USED = . if (Q44_USED <= -1 )
replace Q44_AGE = . if (Q44_AGE <= -1 )
replace Q45_EVER = . if (Q45_EVER <= -1 )
replace Q45_USED = . if (Q45_USED <= -1 )
replace Q45_AGE = . if (Q45_AGE <= -1 )
replace Q46_EVER = . if (Q46_EVER <= -1 )
replace Q46_USED = . if (Q46_USED <= -1 )
replace Q46_AGE = . if (Q46_AGE <= -1 )
replace Q47_EVER = . if (Q47_EVER <= -1 )
replace Q47_USED = . if (Q47_USED <= -1 )
replace Q47_AGE = . if (Q47_AGE <= -1 )
replace Q48_EVER = . if (Q48_EVER <= -1 )
replace Q48_USED = . if (Q48_USED <= -1 )
replace Q48_AGE = . if (Q48_AGE <= -1 )
replace Q49_EVER = . if (Q49_EVER <= -1 )
replace Q49_USED = . if (Q49_USED <= -1 )
replace Q49_AGE = . if (Q49_AGE <= -1 )
replace Q50_EVER = . if (Q50_EVER <= -1 )
replace Q50_USED = . if (Q50_USED <= -1 )
replace Q50_AGE = . if (Q50_AGE <= -1 )
replace Q51_EVER = . if (Q51_EVER <= -1 )
replace Q51_USED = . if (Q51_USED <= -1 )
replace Q51_AGE = . if (Q51_AGE <= -1 )
replace Q52 = . if (Q52 <= -1 )
replace Q53A = . if (Q53A <= -1 )
replace Q53B = . if (Q53B <= -1 )
replace Q53C = . if (Q53C <= -1 )
replace Q54 = . if (Q54 <= -1 )
replace Q54_TST1 = . if (Q54_TST1 <= -1 )
replace Q54_TST2 = . if (Q54_TST2 <= -1 )
replace Q54_MO1 = . if (Q54_MO1 <= -1 )
replace Q54_YR1 = . if (Q54_YR1 <= -1 )
replace Q54_MO2 = . if (Q54_MO2 <= -1 )
replace Q54_YR2 = . if (Q54_YR2 <= -1 )
replace Q54A_1 = . if (Q54A_1 <= -1 )
replace Q54A_2 = . if (Q54A_2 <= -1 )
replace Q54B_1 = . if (Q54B_1 <= -1 )
replace Q54B_2 = . if (Q54B_2 <= -1 )
replace Q54C_1 = . if (Q54C_1 <= -1 )
replace Q54C_2 = . if (Q54C_2 <= -1 )
replace Q54D_1 = . if (Q54D_1 <= -1 )
replace Q54D_2 = . if (Q54D_2 <= -1 )
replace Q54E_1 = . if (Q54E_1 <= -1 )
replace Q54E_2 = . if (Q54E_2 <= -1 )
replace Q54F_1 = . if (Q54F_1 <= -1 )
replace Q54F_2 = . if (Q54F_2 <= -1 )
replace Q54G_1 = . if (Q54G_1 <= -1 )
replace Q54G_2 = . if (Q54G_2 <= -1 )
replace Q54H_1 = . if (Q54H_1 <= -1 )
replace Q54H_2 = . if (Q54H_2 <= -1 )
replace Q54I_1 = . if (Q54I_1 <= -1 )
replace Q54I_2 = . if (Q54I_2 <= -1 )
replace Q54J_1 = . if (Q54J_1 <= -1 )
replace Q54J_2 = . if (Q54J_2 <= -1 )
replace Q54K_1 = . if (Q54K_1 <= -1 )
replace Q54K_2 = . if (Q54K_2 <= -1 )
replace Q54L_1 = . if (Q54L_1 <= -1 )
replace Q54L_2 = . if (Q54L_2 <= -1 )
replace Q54M_1 = . if (Q54M_1 <= -1 )
replace Q54M_2 = . if (Q54M_2 <= -1 )
replace Q54N_1 = . if (Q54N_1 <= -1 )
replace Q54N_2 = . if (Q54N_2 <= -1 )
replace Q54O_1 = . if (Q54O_1 <= -1 )
replace Q54O_2 = . if (Q54O_2 <= -1 )
replace Q55 = . if (Q55 <= -1 )
replace Q56 = . if (Q56 <= -1 )
replace Q57 = . if (Q57 <= -1 )
replace Q57A = . if (Q57A <= -1 )
replace Q58 = . if (Q58 <= -1 )
replace Q58_NO = . if (Q58_NO <= -1 )
replace Q58A_PRI = . if (Q58A_PRI <= -1 )
replace Q58A_SEC = . if (Q58A_SEC <= -1 )
replace Q58A_FAC = . if (Q58A_FAC <= -1 )
replace Q58A_RES = . if (Q58A_RES <= -1 )
replace Q58B_PRI = . if (Q58B_PRI <= -1 )
replace Q58B_SEC = . if (Q58B_SEC <= -1 )
replace Q58B_FAC = . if (Q58B_FAC <= -1 )
replace Q58B_RES = . if (Q58B_RES <= -1 )
replace Q58C_PRI = . if (Q58C_PRI <= -1 )
replace Q58C_SEC = . if (Q58C_SEC <= -1 )
replace Q58C_FAC = . if (Q58C_FAC <= -1 )
replace Q58C_RES = . if (Q58C_RES <= -1 )
replace Q58D_PRI = . if (Q58D_PRI <= -1 )
replace Q58D_SEC = . if (Q58D_SEC <= -1 )
replace Q58D_FAC = . if (Q58D_FAC <= -1 )
replace Q58D_RES = . if (Q58D_RES <= -1 )
replace Q58E_PRI = . if (Q58E_PRI <= -1 )
replace Q58E_SEC = . if (Q58E_SEC <= -1 )
replace Q58E_FAC = . if (Q58E_FAC <= -1 )
replace Q58E_RES = . if (Q58E_RES <= -1 )
replace Q58F_PRI = . if (Q58F_PRI <= -1 )
replace Q58F_SEC = . if (Q58F_SEC <= -1 )
replace Q58F_FAC = . if (Q58F_FAC <= -1 )
replace Q58F_RES = . if (Q58F_RES <= -1 )
replace Q58G_PRI = . if (Q58G_PRI <= -1 )
replace Q58G_SEC = . if (Q58G_SEC <= -1 )
replace Q58G_FAC = . if (Q58G_FAC <= -1 )
replace Q58G_RES = . if (Q58G_RES <= -1 )
replace Q58H_PRI = . if (Q58H_PRI <= -1 )
replace Q58H_SEC = . if (Q58H_SEC <= -1 )
replace Q58H_FAC = . if (Q58H_FAC <= -1 )
replace Q58H_RES = . if (Q58H_RES <= -1 )
replace Q58I_PRI = . if (Q58I_PRI <= -1 )
replace Q58I_SEC = . if (Q58I_SEC <= -1 )
replace Q58I_FAC = . if (Q58I_FAC <= -1 )
replace Q58I_RES = . if (Q58I_RES <= -1 )
replace Q58J_PRI = . if (Q58J_PRI <= -1 )
replace Q58J_SEC = . if (Q58J_SEC <= -1 )
replace Q58J_FAC = . if (Q58J_FAC <= -1 )
replace Q58J_RES = . if (Q58J_RES <= -1 )
replace Q59_SER = . if (Q59_SER <= -1 )
replace Q59_FAC = . if (Q59_FAC <= -1 )
replace Q59_NO = . if (Q59_NO <= -1 )
replace Q60_SER = . if (Q60_SER <= -1 )
replace Q60_FAC = . if (Q60_FAC <= -1 )
replace Q60_NO = . if (Q60_NO <= -1 )
replace Q61_SER = . if (Q61_SER <= -1 )
replace Q61_FAC = . if (Q61_FAC <= -1 )
replace Q61_NO = . if (Q61_NO <= -1 )
replace Q62_SER = . if (Q62_SER <= -1 )
replace Q62_FAC = . if (Q62_FAC <= -1 )
replace Q62_NO = . if (Q62_NO <= -1 )
replace Q63_SER = . if (Q63_SER <= -1 )
replace Q63_FAC = . if (Q63_FAC <= -1 )
replace Q64_SER = . if (Q64_SER <= -1 )
replace Q64_FAC = . if (Q64_FAC <= -1 )
replace Q65_SER = . if (Q65_SER <= -1 )
replace Q65_FAC = . if (Q65_FAC <= -1 )
replace Q66_SER = . if (Q66_SER <= -1 )
replace Q66_FAC = . if (Q66_FAC <= -1 )
replace Q67_SER = . if (Q67_SER <= -1 )
replace Q67_FAC = . if (Q67_FAC <= -1 )
replace Q68_SER = . if (Q68_SER <= -1 )
replace Q68_FAC = . if (Q68_FAC <= -1 )
replace Q69_SER = . if (Q69_SER <= -1 )
replace Q69_FAC = . if (Q69_FAC <= -1 )
replace Q70 = . if (Q70 <= -1 )
replace Q70A = . if (Q70A <= -1 )
replace Q71 = . if (Q71 <= -1 )
replace Q72 = . if (Q72 <= -1 )
replace Q73 = . if (Q73 <= -1 )
replace Q74 = . if (Q74 <= -1 )
replace Q74A_MO = . if (Q74A_MO <= -1 )
replace Q74A_YR = . if (Q74A_YR <= -1 )
replace Q74A_TOT = . if (Q74A_TOT <= -1 )
replace Q74A_GIV = . if (Q74A_GIV <= -1 )
replace Q74A_NO = . if (Q74A_NO <= -1 )
replace Q74A_PL = . if (Q74A_PL <= -1 )
replace Q74B_MO = . if (Q74B_MO <= -1 )
replace Q74B_YR = . if (Q74B_YR <= -1 )
replace Q74B_TOT = . if (Q74B_TOT <= -1 )
replace Q74B_GIV = . if (Q74B_GIV <= -1 )
replace Q74B_NO = . if (Q74B_NO <= -1 )
replace Q74B_PL = . if (Q74B_PL <= -1 )
replace Q75 = . if (Q75 <= -1 )
replace Q76 = . if (Q76 <= -1 )
replace Q76A_MO = . if (Q76A_MO <= -1 )
replace Q76A_YR = . if (Q76A_YR <= -1 )
replace Q76B = . if (Q76B <= -1 )
replace Q77_MO = . if (Q77_MO <= -1 )
replace Q77_YR = . if (Q77_YR <= -1 )
replace Q78_MO = . if (Q78_MO <= -1 )
replace Q78_YR = . if (Q78_YR <= -1 )
replace Q79 = . if (Q79 <= -1 )
replace Q79A = . if (Q79A <= -1 )
replace Q79A_MC1 = . if (Q79A_MC1 <= -1 )
replace Q79A_MC2 = . if (Q79A_MC2 <= -1 )
replace Q79A_MC3 = . if (Q79A_MC3 <= -1 )
replace Q79A_MC4 = . if (Q79A_MC4 <= -1 )
replace Q80 = . if (Q80 <= -1 )
replace Q81 = . if (Q81 <= -1 )
replace Q81A = . if (Q81A <= -1 )
replace Q81B = . if (Q81B <= -1 )
replace Q81C = . if (Q81C <= -1 )
replace Q81D = . if (Q81D <= -1 )
replace Q81E = . if (Q81E <= -1 )
replace Q81F = . if (Q81F <= -1 )
replace Q81G = . if (Q81G <= -1 )
replace Q81H = . if (Q81H <= -1 )
replace Q81I = . if (Q81I <= -1 )
replace Q81J = . if (Q81J <= -1 )
replace Q82 = . if (Q82 <= -1 )
replace Q83 = . if (Q83 <= -1 )
replace Q83A = . if (Q83A <= -1 )
replace Q84 = . if (Q84 <= -1 )
replace Q84_PER = . if (Q84_PER <= -1 )
replace Q85 = . if (Q85 <= -1 )
replace BATCHNO = . if (BATCHNO <= -1 )
replace CORRFAC = . if (CORRFAC <= -1 )
replace ALCHONLY = . if (ALCHONLY <= -1 )
replace STRATUM = . if (STRATUM <= -1 )
replace REGION = . if (REGION <= -1 )
replace LOS = . if (LOS <= -1 )
replace TRT_DUR = . if (TRT_DUR <= -1 )
replace AGEA = . if (AGEA <= -1 )
replace AGED = . if (AGED <= -1 )
replace TXTYPE = . if (TXTYPE <= -1 )
replace NUMDUALA = . if (NUMDUALA <= -1 )
replace NUMDUALD = . if (NUMDUALD <= -1 )
replace NUMDXA = . if (NUMDXA <= -1 )
replace CWGHT = . if (CWGHT <= -1.0000000 )
replace CWT1 = . if (CWT1 <= -1.0000000 )
replace CWT2 = . if (CWT2 <= -1.0000000 )
replace CWT3 = . if (CWT3 <= -1.0000000 )
replace CWT4 = . if (CWT4 <= -1.0000000 )
replace CWT5 = . if (CWT5 <= -1.0000000 )
replace CWT6 = . if (CWT6 <= -1.0000000 )
replace CWT7 = . if (CWT7 <= -1.0000000 )
replace CWT8 = . if (CWT8 <= -1.0000000 )
replace CWT9 = . if (CWT9 <= -1.0000000 )
replace CWT10 = . if (CWT10 <= -1.0000000 )
replace CWT11 = . if (CWT11 <= -1.0000000 )
replace CWT12 = . if (CWT12 <= -1.0000000 )
replace CWT13 = . if (CWT13 <= -1.0000000 )
replace CWT14 = . if (CWT14 <= -1.0000000 )
replace CWT15 = . if (CWT15 <= -1.0000000 )
replace CWT16 = . if (CWT16 <= -1.0000000 )
replace CWT17 = . if (CWT17 <= -1.0000000 )
replace CWT18 = . if (CWT18 <= -1.0000000 )
replace CWT19 = . if (CWT19 <= -1.0000000 )
replace CWT20 = . if (CWT20 <= -1.0000000 )
replace CWT21 = . if (CWT21 <= -1.0000000 )
replace CWT22 = . if (CWT22 <= -1.0000000 )
replace CWT23 = . if (CWT23 <= -1.0000000 )
replace CWT24 = . if (CWT24 <= -1.0000000 )
replace CWT25 = . if (CWT25 <= -1.0000000 )
replace CWT26 = . if (CWT26 <= -1.0000000 )
replace CWT27 = . if (CWT27 <= -1.0000000 )
replace CWT28 = . if (CWT28 <= -1.0000000 )
replace CWT29 = . if (CWT29 <= -1.0000000 )
replace CWT30 = . if (CWT30 <= -1.0000000 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

